@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-LOG_NAME = 'gourd'
+LOGGER_NAME = 'gourd'
 
 BACKLOG = 65535
 
