@@ -131,7 +131,7 @@ class GourdTcp(asyncore.dispatcher, CallBackMgr):
         self.bind((host, port))
         self.listen(self.request_queue_size)
 
-        asyncore.loop(map=self._map)
+        asyncore.loop(use_poll=True, map=self._map)
 
     def make_rsp(self, *args, **kwargs):
         """
@@ -210,7 +210,7 @@ class GourdUdp(asyncore.dispatcher, CallBackMgr):
         self.create_socket(socket.AF_INET, socket.SOCK_DGRAM)
         self.bind((host, port))
 
-        asyncore.loop(map=self._map)
+        asyncore.loop(use_poll=True, map=self._map)
 
     def make_rsp(self, *args, **kwargs):
         """
